@@ -137,7 +137,7 @@ enum heif_auxiliary_track_info_type
 };
 
 LIBHEIF_API
-heif_auxiliary_track_info_type heif_track_get_auxiliary_info_type(const heif_track*);
+enum heif_auxiliary_track_info_type heif_track_get_auxiliary_info_type(const heif_track*);
 
 LIBHEIF_API
 const char* heif_track_get_auxiliary_info_type_urn(const heif_track*);
